From 58a80d9ecd8e67c69a2f7353bda9b08563cbc7b3 Mon Sep 17 00:00:00 2001
From: Administrator <admin>
Date: Mon, 02 Aug 2021 15:23:39 +0800
Subject: [PATCH] 报名清册

---
 src/router/views/index.js |  128 ++++++++++++++++++++++++------------------
 1 files changed, 72 insertions(+), 56 deletions(-)

diff --git a/src/router/views/index.js b/src/router/views/index.js
index b031e53..fe947e1 100644
--- a/src/router/views/index.js
+++ b/src/router/views/index.js
@@ -661,59 +661,75 @@
                 import ( /* webpackChunkName: "views" */ '@/views/trainExam/index')
         }]
     },
-  {
-    path: '/applyexam',
-    redirect: '/applyexam/index',
-    component: Layout,
-    children: [{
-      path: 'index',
-      name: '报名考试',
-      meta: {
-        i18n: 'index',
-      },
-      component: () =>
-        import( /* webpackChunkName: "views" */ '@/views/applyexam/index')
-    }]
-  },
-  {
-    path: '/startexam',
-    redirect: '/startexam/index',
-    component: Layout,
-    children: [{
-      path: 'index',
-      name: '开始考试',
-      meta: {
-        i18n: 'index',
-      },
-      component: () =>
-        import( /* webpackChunkName: "views" */ '@/views/startexam/index')
-    }]
-  },
-  {
-    path: '/titleDetails',
-    component: () =>
-      import( /* webpackChunkName: "views" */ '@/views/exam/topicDetails')
-  },
-  {
-    path: '',
-    component: Layout,
-    children: [{
-      path: '/exam/subjects/:id',
-      component: () => import('@/views/exam/examSubjects'),
-      name: '题目管理',
-      title: '题目管理',
-      noCache: true
-    }]
-  },
-  {
-    path: '',
-    component: Layout,
-    children: [{
-      path: '/startexam/:id',
-      component: () => import('@/views/startexam/index'),
-      name: '开始考试',
-      title: '开始考试',
-      noCache: true
-    }]
-  },
-]
+    {
+        path: '/applyexam',
+        redirect: '/applyexam/index',
+        component: Layout,
+        children: [{
+            path: 'index',
+            name: '报名考试',
+            meta: {
+                i18n: 'index',
+            },
+            component: () =>
+                import ( /* webpackChunkName: "views" */ '@/views/applyexam/index')
+        }]
+    },
+    {
+        path: '/applydetailed',
+        redirect: '/applydetailed/index',
+        component: Layout,
+        children: [{
+            path: 'index',
+            name: '报名清册',
+            meta: {
+                i18n: 'index',
+            },
+            component: () =>
+                import ( /* webpackChunkName: "views" */ '@/views/applydetailed/index')
+        }]
+    },
+    {
+        path: '/startexam',
+        redirect: '/startexam/index',
+        component: Layout,
+        children: [{
+            path: 'index',
+            name: '开始考试',
+            meta: {
+                i18n: 'index',
+            },
+            component: () =>
+                import ( /* webpackChunkName: "views" */ '@/views/startexam/index')
+        }]
+    },
+    {
+        path: '/titleDetails',
+        component: () =>
+            import ( /* webpackChunkName: "views" */ '@/views/exam/topicDetails')
+    },
+    {
+        path: '',
+        component: Layout,
+        children: [{
+            path: '/exam/subjects/:id',
+            component: () =>
+                import ('@/views/exam/examSubjects'),
+            name: '题目管理',
+            title: '题目管理',
+            noCache: true
+        }]
+    },
+    {
+        path: '',
+        component: Layout,
+        children: [{
+            path: '/startexam/:id',
+            component: () =>
+                import ('@/views/startexam/index'),
+            name: '开始考试',
+            title: '开始考试',
+            noCache: true
+        }]
+    },
+]
\ No newline at end of file

--
Gitblit v1.9.3